# flake8: noqa
__version__ = "0.3.0"
__author__ = "Akio Taniguchi"


# aliases
from .abc import *
from .dataclasses import *
